function y=bootstrapetl(PandL_data,number_resamples,cl)
% BOOTSTRAPETL Bootstrapped ETL for specified confidence level
%
% Function estimates the bootstrapped ETL, 
% for confidence level and holding period implied by data frequency.
% 
% The first argument is a vector of daily portfolio P/L data, the second is the 
% number of resamples to be taken in the bootstrapping procedure, and the 
% third is the VaR confidence level (and is a scalar). 
%
% Revised by Kevin Dowd, November 11th, 2001.
% ************************************************************************
% 
% Determine if there are three arguments
%
if nargin<3,
    error('Too few arguments');
end
if nargin>3,
    error('Too many arguments');
end
% 
% Preprocess data
%
unsorted_loss_data=-PandL_data; % Derives L/P data from inputted P/L data
losses_data=sort(unsorted_loss_data); % Puts losses in ascending order
n=length(losses_data);
% 
% Check that inputs have correct dimensions
%
[cl_rows,cl_cols]=size(cl);
if max(cl_rows,cl_cols)>1
    error('Confidence level must be a scalar');
end
[number_resamples_rows,number_resamples_cols]=size(number_resamples);
if max(number_resamples_rows,number_resamples_cols)>1
    error('Number of resamples must be a scalar');
end
%
% Check that inputs obey sign and value restrictions
%
if cl>=1
    error('Confidence level must be less than 1');
end
if number_resamples<=0
    error('Number of resamples must be at least 1')
end
%
% ETL estimation
%
etl= bootstrp(number_resamples,'hsetl',losses_data,cl);
y=mean(etl);
