function y=christoffersen2backtest(PandL,VaR,cl)
% CHRISTOFFERSEN2BACKTEST Second Christoffersen backtest  (of independence)
%
% Function carries out the second Christoffersen backtest (ie, test of independence) 
% for a VaR risk measurement model, for specified VaR confidence level.
%
% The first argument is a vector of portfolio P/L observations, the second is a corresponding
% vector of VaR forecasts, and the third is the VaR confidence level. 
% 
% The output is the probability, given the data set, that the null hypothesis (ie, 
% independence) is correct. 
% 
% Reference: Peter F. Christoffersen, "Evaluating interval forecasts." International
% Economic Review, Vol. 39, 1998, pp.841-62.
%
% Revised by Kevin Dowd, February 21st, 2001.
% *****************************************************************************************
% 
n=length(PandL);                        % Number of observations
p=1-cl;                                            % Probability of a failure under null hypothesis
excess_loss=-PandL-VaR;        % Derives excess loss
% excess_loss(excess_loss<=0)=[];    % Gets rid of negative or zero excess loss observations
% VaR(excess_loss<=0)=[];
% 
% Building exception table
%
T00=0; T01=0; T10=0; T11=0;
for i=2:n
    if excess_loss(i)<=0
        if excess_loss(i-1)<=0
            T00=T00+1;
        else
            T10=T10+1;    
        end
    end
   if excess_loss(i)>0
        if excess_loss(i-1)
            T01=T01+1;
        else
            T11=T11+1;
        end
   end
end
T00
T01
T10
T11
%
% Recover pie terms
%
pie0=T01/(T00+T01)
pie1=T11/(T10+T11)
%
% Likelihood ratio test statistic
%
LR=-2*log((((1-p)^(T00+T10))*(p^(T01+T11)))+2*log((((1-pie0)^T00))*(pie0^T01)*((1-pie1)^(T10))*pie1^T11))
% 
% Probability that null hypothesis (independence) is correct
%
y=1-chi2cdf(LR,1);

