function y=cornishfishervar(mu, sigma, skew, kurtosis,cl)
% CORNISHFISHERVAR Computes VaR using the Cornish-Fisher adjustment for non-normality
%
% Function estimates the VaR for near-normal P/L using the Cornish-Fisher adjustment for 
% non-normality, for specified confidence level.
% 
% The first four arguments are the first four moments of the P/L distribution. The fifth argument
% is the VaR confidence level.
% 
% cl must be a scalar, and hp is implied by data frequency. 
%
% Based on Peter Zangari, "A VaR methodology for portfolios that include options." RiskMetrics
% Monitor, First quarter, 1996, pp. 4-12.
% 
% Revised by Kevin Dowd, February 8th, 2001.
% ***************************************************************************************************
% Normal variate
%
z=norminv(1-cl,0,1);
%
% Deriving adjustment factor
%
adjustment=(1/6)*(z^2-1)*skew+(1/24)*(z^3-3*z)*(kurtosis-3)-(1/36)*(2*z^3-5*z)*skew^2;
%
% VaR estimation
%
y=-sigma*(z+adjustment)-mu; %VaR 