function y=gumbelcopulavar(beta,cl)
% GUMBELCOPULAVAR Estimates VaR of a set of positions using the Gumbel copula
%
% This function estimates the VaR of a two asset portfolio using a Gumbel copula. The returns of the two assets
% are assumed to be derived from standard normal marginal distributions.
%
% The first input argument is the assumed beta parameter value for the 
% Gumbel distribution, and the second is the VaR confidence level.
%
% NB Can only be used for positive VaRs (ie, confidence level must not be low). 
% 
% Revised by Kevin Dowd, November 8th, 2001.
% *****************************************************************************************

no_of_iterations=100000;

x=randn(no_of_iterations,1);
y=randn(no_of_iterations,1);

PandL=(x+y)/2;

u=normcdf(x);
v=normcdf(y);

OS=ceil(no_of_iterations*(1-cl))

% Gumbel copula

cdf=exp(-((-(log(u)).^(beta))-((-log(v)).^(beta))).^(1/beta)); % Gumbel c. 
S=[cdf PandL]; 
Z=sort(S);
gumbelvar=-Z(OS,2);

%

y=gumbelvar;


