function y=normalvarhotspots(vc_matrix,mu, positions,cl,hp)
% NORMALVARHOTSPOTS Hot spots for normal VaR
%
% Function estimates the hot spots (or vector of incremental VaRs) for a portfolio 
% assuming individual asset returns are normally distributed, for specified confidence 
% level and holding period.
% 
% The first argument is the assumed variance-covariance matrix for returns, the second
% is the vector of expected position returns, the third is the vector of positions, the
% fourth is the VaR confidence level (scalar), and the last is the VaR holding 
% period (scalar). 
%
% Revised by Kevin Dowd, February 18th, 2001.
% *****************************************************************************************
% 
% To check that positions vector read as a scalar or row vector 
%
[positions_rows,positions_cols]=size(positions);
if positions_rows>positions_cols
    positions=positions';
end
% 
% To check that expected returns vector is read as a scalar or row vector 
%
[mu_rows,mu_cols]=size(mu);
if mu_rows>mu_cols
    mu=mu';
end
%
% Check that dimensions are correct
%
if max(size(mu))~=max(size(positions))
    error('Positions vector and expected returns vector must have same size')
end
if max(size(positions))~=max(size(vc_matrix))
    error('Positions vector and variance-covariance matrix must have compatible dimensions')
end
%
% Check that inputs obey sign and value restrictions
%
if cl>=1
    error('Confidence level must be less than 1');
end
if cl<=0
    error('Confidence level must be greater than 0');
end
if hp<=0
    error('Holding period must be greater than 0');
end
%
% VaR estimation
%
var=-mu*positions'*hp-norminv(1-cl,0,1)*positions*vc_matrix*positions'*sqrt(hp); %VaR 
   for i=1:length(positions)
    x=positions;
   x(i)=0;
    ivar(i)=var+mu*x'*hp+norminv(1-cl,0,1)*x*vc_matrix*x'*sqrt(hp);
end
y=ivar;

