function y=Kuiper_test_stat(number_trials,sample_size,confidence_interval)
% Produces plots of cumulative density for the Kuiper test, and confidence 
% interval for the Kuiper test stat.
%
% Inputs:
%   Number of trials.
%   Sizes of trial samples.
%   Confidence interval expressed as a fraction of 1.
%
% Revised by Kevin Dowd, December 27, 2004.
% *****************************************************************
tic
%
% Read back input parameters
%
number_trials
sample_size
m=number_trials;
n=sample_size;
confidence_interval
%
% Random number generation
%
data=zeros(m,n);
data=normrnd(0,1,m,n);
%
for i=1:m
   trial_sample=data(i,:);
   ordered_trial_sample=sort(trial_sample);
   for j=1:n
      cdf_diff(j)=j/n-normcdf(ordered_trial_sample(j),0,1);
   end
   Kuiper_test_stat(i)=max(cdf_diff)-min(cdf_diff);
end
Kuiper_test_stat=sort(Kuiper_test_stat);

%
% Obtain confidence interval
%
lower_bound_index=round(m*(1-confidence_interval)/2);
upper_bound_index=round(m*(confidence_interval+(1-confidence_interval)/2));
confidence_interval_for_Kuiper_test_stat=[Kuiper_test_stat(lower_bound_index) Kuiper_test_stat(upper_bound_index)]
%
% Plot 
%
cdf=1/m:1/m:1;
plot(Kuiper_test_stat,cdf)
xlabel('Kuiper test statistic','horizontal','center','Fontweight','bold');
ylabel('Cumulative probability','rotation',90,'horizontal','center','Fontweight','bold');
title(['Cumulative density for Kuiper test statistic'],'FontSize',12,'Fontweight','bold');
set(gcf, 'color', 'white');
%
toc
