function y=gparetoes(x,beta, zeta,threshold_prob,cl)
% GPARETOETL ES for Generalised Pareto P/L
%
% Function estimates the ES of a portfolio assuming losses are distributed
% as a generalised Pareto. 
%  
% The first argument is a vector of daily P/L data, the second
% is the assumed scale parameter beta, the third is assumed the tail index,
% the fourth is the threshold probability - the probability corresponding to the 
% threshold u, and x, the fifth is the VaR confidence level. 
%
% Source: A. McNeil, (1999) "Extreme value theory for risk managers." Mimeo. ETHZ. 
%
% Revised by Kevin Dowd, March 27, 2001.
% *****************************************************************************************
% 
n=length(x);
x=sort(x);
Nu=fix(threshold_prob*n);
u=x(n-Nu);
y=(u+(beta/zeta)*((((1/threshold_prob)*(1-cl))^(-zeta))-1))/(1-zeta)+(beta-zeta*u)/(1-zeta);
