function y=hsesfigure(PandL_data,cl)
% HSESFIGURE  Figure of historical simuation VaR and ES and histogram of L/P
% 
% Function gives figure showing the historical VaR and ES and histogram of L/P of a portfolio 
% for specified confidence level and holding period implied by data.
%
% The first argument is a vector of daily portfolio P/L data and the second
% is the VaR confidence level. 
% 
% NB: cl is a scalar, and output is a scalar.
%
% Revised by Kevin Dowd, November 26th, 2001.
% *******************************************************************
% 
% Determine if there are two arguments, and ensure that arguments
% are read as intended
%
if nargin<2,
    error('Too few arguments');
end
if nargin>2,
    error('Too many arguments');
end
if nargin ==2
    n=length(PandL_data);
end
% 
% Check that inputs have correct dimensions
%
[cl_rows,cl_cols]=size(cl);
if max(cl_rows,cl_cols)>1
    error('Confidence level must be a scalar');
end
%
% Check that inputs obey sign and value restrictions
%
if cl>=1
    error('Confidence level must be less than 1');
end
%
% VaR and ES estimation
%
var=hsvar(PandL_data,cl)
es=hses(PandL_data,cl)
%
% Histogram
%
hist(-PandL_data, 50); % Histogram with 50 bins
hold on;
n=hist(-PandL_data,50); max(n); % Counts for maximum frequency
%
% Insert line showing VaR
%
v=[0,.625*max(n)];                           % Coordinates for VaR line
u=var*ones(size(v));                       % Coordinates for VaR line
line=plot(u,v, 'Color','black');          % VaR line
%
%Insert line showing ES
%
w=[0,.45*max(n)];                               % Coordinates for ES line
z=es*ones(size(w));                          % Coordinates for ES line
line=plot(z,w,'Color','black');           % ES line
%
cl_for_label=100*cl;                        % Input to confidence level label
% 
% VaR line label
%
text(var,.75*max(n),['VaR at ',num2str(cl_for_label),'% CL'],'Fontweight','bold','horizontal','center')
text(var,.70*max(n),['= ',num2str(var)],'Fontweight','bold','horizontal','center')
%
% ES line label
%
text(es,.55*max(n),['ES ='],'Fontweight','bold','horizontal','center')
text(es,.5*max(n),[num2str(es)],'Fontweight','bold','horizontal','center')
%
% Axis labels
%
xlabel('Loss (+) / Profit (-)','horizontal','center','Fontweight','bold');
ylabel('Frequency','rotation',90,'horizontal','center','Fontweight','bold');
%
% Title 
%
title(['Historical Simulation VaR and ES'],'FontSize',12,'Fontweight','bold');
hold off;

