function y=kernelvar_boxkernel(PandL_data,cl)
% Calculates VaR using a box kernel approach
% 
% The output consists of a scalar VaR for specified confidence level.
%
% Inputs are:
% * PandL data set;
% * confidence level.
%
% Written by Kevin Dowd, November 16, 2003
% *************************************************
%
mu=mean(PandL_data);
sigma=std(PandL_data);
delta_x=(max(PandL_data)-min(PandL_data))/1000;
xvalues=mu-4*sigma:delta_x:mu+4*sigma;
n=length(xvalues);
% 
% Obtain pdf values 
% 
kernelpdf=ksdensity(PandL_data,xvalues,'kernel','box','npoints',n);
%
% Obtain cdf values
%
cdf(1)=kernelpdf(1)*delta_x;
for i=2:length(xvalues)
    cdf(i)=kernelpdf(i)*delta_x+cdf(i-1);
end
plot(xvalues,kernelpdf)
% 
% Derivation of required percentile
%
cdf_indices_less_than_prob=find(cdf<cl); 
% Gives vector of indices for all cdf-values less than probability.
max_cdf_index_less_than_prob=length(cdf_indices_less_than_prob);
% Gives index of cdf-value just less than probability.
lower_x_bound=xvalues(max_cdf_index_less_than_prob);
% Gives x-value just below specified probability.
upper_x_bound=xvalues(max_cdf_index_less_than_prob+1);
% Gives x-value just above specified probability.
var=(lower_x_bound+upper_x_bound)/2; % Desired percentile, ie, answer.
y=var;
