function dbpensionvar(mu,sigma,p,life_expectancy,number_trials,cl)
% DBPENSIONVAR Generates Monte Carlo VaR for DB pension in 
% Chapter 6.7.
%
% The arguments are as follows: expected rate of return on pension- 
% fund assets, volatility of rate of return of pension-fund assets,
% probability of unemployment in any period, life expectancy, number
% of trials, and VaR confidence level.
%
% Revised by Kevin Dowd, November 11th, 2001.
% ********************************************************************
%
% PARAMETER SETTING
%
contribution_rate=0.15;
initial_income=25;
income_growth_rate=0.02;
M=number_trials;
L=life_expectancy;
% r is return on investment
%
% ASSET SIDE
%
for j=1:M
fund(1,j)=contribution_rate*initial_income;
years_contributed(1,j)=1;
    for i=2:40
        r(i,j)=mu+sigma*randn;
        employment_state(i,j)=binornd(1,1-p);
        employment_income(i,j)=initial_income*exp(income_growth_rate*(i-1));
        actual_income(i,j)=employment_state(i,j)*employment_income(i,j);
        contribution(i,j)=contribution_rate*actual_income(i,j);
        fund(i,j)=contribution(i,j)+fund(i-1,j)*(1+r(i,j));
        terminal_fund(j)=fund(i,j);
        terminal_return(j)=r(i,j);
        years_contributed(i,j)=employment_state(i,j)+years_contributed(i-1,j);
        total_years_contributed(j)=years_contributed(i,j);
    end
    % terminal_fund(j)
end
mean_terminal_fund=mean(terminal_fund);
std_terminal_fund=std(terminal_fund);
%
% LIABILITY SIDE
%
terminal_employment_income=(1-p)*initial_income*exp(income_growth_rate*39);
for j=1:M
    pension(j)=(total_years_contributed(j)/40)*terminal_employment_income;
    annuity_rate(j)=.04;
    implied_fund(j)=pvfix(annuity_rate(j),L-65,pension(j));
end
mean_terminal_employment_income=mean(terminal_employment_income);
mean_t_years_contributed=mean(total_years_contributed);
mean_pension=mean(pension);
mean_implied_fund=mean(implied_fund);
std_implied_fund=std(implied_fund);
%
% PROFIT LOSS AND VAR
%
Profit_or_loss=terminal_fund-implied_fund;
mean_Profit_or_loss=mean(Profit_or_loss);
std_Profit_or_loss=std(Profit_or_loss);
%
hist(-Profit_or_loss, 20);
%
hsvar(Profit_or_loss,cl)