function defaultriskybondvar(r,rf,coupon,sigma,amount_invested,...
recovery_rate, p, number_trials, hp, cl)
% DEFAULTRISKYBONDVAR Generates Monte Carlo VaR for default risky
% bond portfolio in Chapter 6.4.
%
% The arguments are: the spot (interest) rate, assumed to be 
% flat; the risk-free rate; the coupon rate; the amount 
% invested; the recovery rate; the probability of default;
% the number of trials; the VaR holding period and confidence
% level. 
%
% Revised by Kevin Dowd, November 8th, 2001.
% ***************************************************************
%
M=number_trials;
delta=recovery_rate;
ann_hp=hp/360;
% r=spot_rate_at_maturity_term;
% rf=risk-free rate;
% R equals spot rate prevailing at end of hp/2 with term equal to hp/2
initial_bond_value=coupon*((1+rf)/(1+r))^(ann_hp/2)+(1+coupon)/((1+r)^(ann_hp));
number_of_bonds=amount_invested/initial_bond_value;
%
z=randn(1,M);
size(z)
for j=1:M
    R(j)=exp(r+sigma*sqrt(hp/2)*z(j)); % Random realisation of spot rate with 
    % term hp/2
    interim_default_state(j)=binornd(1,p); % Determines whether default occurs at hp/2
    terminal_default_state(j)=binornd(1,p); % Determines whether default occurs at hp
    if interim_default_state(j)==0
        if terminal_default_state(j)==0
            terminal_bond_value(j)=coupon*(1+rf)^(ann_hp/2)+(1+coupon);
        else
            terminal_bond_value(j)=coupon*((1+rf)^(ann_hp/2))+delta*(1+coupon);
        end
    else
        interim_bond_value(j)=delta*(coupon+((1+coupon)/(1+R(j))^(ann_hp/2)));
        terminal_bond_value(j)=((1+rf)^(ann_hp/2))*interim_bond_value(j);
    end
end
%
Profit_or_loss=number_of_bonds*(terminal_bond_value-initial_bond_value);
% Convert to P/L
hist(-Profit_or_loss, 20)
%
hsvar(Profit_or_loss,cl)