function y=normaleshotspots(vc_matrix,mu, positions,cl,hp)
% Hot spots for normal ES
%
% Function estimates the ES hot spots (or vector of incremental ESs) for a portfolio 
% assuming individual asset returns are normally distributed, for specified confidence 
% level and holding period.
% 
% The first argument is the assumed variance-covariance matrix for returns, the second
% is the vector of expected position returns, the third is the vector of positions, the
% fourth is the VaR confidence level (scalar), and the last is the VaR holding 
% period (scalar). 
%
% Revised by Kevin Dowd, February 20th, 2001.
% *****************************************************************************************
% 
% To check that positions vector read as a scalar or row vector 
%
[positions_rows,positions_cols]=size(positions);
if positions_rows>positions_cols
    positions=positions';
end
% 
% To check that expected returns vector is read as a scalar or row vector 
%
[mu_rows,mu_cols]=size(mu);
if mu_rows>mu_cols
    mu=mu';
end
%
% Check that dimensions are correct
%
if max(size(mu))~=max(size(positions))
    error('Positions vector and expected returns vector must have same size')
end
if max(size(positions))~=max(size(vc_matrix))
    error('Positions vector and variance-covariance matrix must have compatible dimensions')
end
%
% Check that inputs obey sign and value restrictions
%
if cl>=1
    error('Confidence level must be less than 1');
end
if cl<=0
    error('Confidence level must be greater than 0');
end
if hp<=0
    error('Holding period must be greater than 0');
end
%
% VaR and ES estimation
%
%        Begin with portfolio ES
%
var=-mu*positions'*hp-norminv(1-cl,0,1)*positions*vc_matrix*positions'*sqrt(hp); %VaR 
n=1000;                                     % Number of slices into which tail is divided 
cl0=cl;                                        % Initial confidence level
term=var;                                                                                             
delta_cl=(1-cl)/n;                    % Increment to confidence level as each slice is taken
     for k=1:n-1
        cl=cl0+k*delta_cl;           % Revised cl
        term=term-mu*positions'*hp-norminv(1-cl,0,1)*positions*vc_matrix*positions'*sqrt(hp);
     end;
portfolio_es=term/n;                                           % Portfolio ES
%
%
for j=1:length(positions)
    x=positions;
    x(j)=0;
    term(j)=-mu*x'*hp-norminv(1-cl,0,1)*x*vc_matrix*x'*sqrt(hp);                                                                                           
    for k=1:n-1
        cl=cl0+k*delta_cl;           % Revised cl
        term(j)=term(j)-mu*x'*hp-norminv(1-cl,0,1)*x*vc_matrix*x'*sqrt(hp);
     end;
    es(j)=term(j)/n;                                           % ES on portfolio minus position j
    ies(j)=portfolio_es-es(j);                                             % Incremental ES
end
y=ies;


