function y=variancecovariancees(vc_matrix,mu, positions,cl,hp)
% Variance-covariance ES for normally distributed returns
%
% Function estimates the variance-covariance ES of a portfolio assuming individual asset 
% returns are normally distributed, for specified confidence level and holding period.
% 
% The first argument is the assumed variance-covariance matrix for returns, the second
% is the vector of expected position returns, the third is the vector of positions, 
% the fourth is the VaR confidence level (scalar or vector), and the last is the VaR holding 
% period (scalar or vector). 
%
% Revised by Kevin Dowd, February 18th, 2001.
% *****************************************************************************************
%
% To check that cl is read as a row vector 
%
[cl_rows,cl_cols]=size(cl);
if cl_rows>cl_cols
    cl=cl';
end
%
% To check that hp is read as a column vector
%
[hp_rows,hp_cols]=size(hp);
if hp_rows>hp_cols
    hp=hp';
end
% 
% To check that positions vector read as a scalar or row vector 
%
[positions_rows,positions_cols]=size(positions);
if positions_rows>positions_cols
    positions=positions';
end
% 
% To check that expected returns vector is read as a scalar or row vector 
%
[mu_rows,mu_cols]=size(mu);
if mu_rows>mu_cols
    mu=mu';
end
%
% Check that dimensions are correct
%
if max(size(mu))~=max(size(positions))
    error('Positions vector and expected returns vector must have same size')
end
if max(size(positions))~=max(size(vc_matrix))
    error('Positions vector and variance-covariance matrix must have compatible dimensions')
end
%
% Check that inputs obey sign and value restrictions
%
if max(cl)>=1
    error('Confidence level must be less than 1');
end
if min(cl)<=0
    error('Confidence level must be greater than 0');
end
if min(hp)<=0
    error('Holding period must be greater than 0');
end
%
% VaR estimation
%
for i=1:length(cl)
    for j=1:length(hp)
        var(i,j)=-mu*positions'*hp(j)-norminv(1-cl(i),0,1)*positions*vc_matrix*positions'*sqrt(hp(j)); %VaR 
        %
        % ES estimation
        %
        n=1000;                                           % Number of slices into which tail is divided 
        cl0(i)=cl(i);                                       % Initial confidence level
        term(i,j)=var(i,j);                                                                                             
        delta_cl(i)=(1-cl(i))/n;                    % Increment to confidence level as each slice is taken
            for k=1:n-1
            cl(i)=cl0(i)+k*delta_cl(i);           % Revised cl
            term(i,j)=term(i,j)-mu*positions'*hp(j)-norminv(1-cl(i),0,1)*positions*vc_matrix*positions'*sqrt(hp(j));
        end;
        es(i,j)=term(i,j)/n;                                           % ETL
    end
end
y=es';

