function y=blackscholescallprice(stock_price, strike,rf, sigma, t)
% Function derives the price of a European call option using the Black-Scholes 
% approach. 
%
% There are five arguments: the first is the stock price, the second is the strike price, the 
% third is the risk-free rate, the fourth is volatility, and the fifth is the term to maturity. 
% This case corresponds to the standard BS call option.
%
% Rates are expressed in annualised terms and maturity is in years.
%
% Reference: Hull, 5th edition, p. 246.
%
% Revised by Kevin Dowd, February 28, 2005.
% *****************************************************************************************
%
% Interpret arguments
%
S=stock_price;
X=strike;
%
% d terms
%
d1=(log(S/X)+(rf+(sigma^2)/2)*t)/(sigma*sqrt(t))
d2=d1-sigma*sqrt(t)
%
% Option price
%
y=stock_price*normcdf(d1)-exp(-rf*t)*strike*normcdf(d2);
