function y=shortblackscholesputvar(stock_price,strike,r,mu,sigma,maturity, cl, hp)
% Function derives the VaR of a short Black Scholes put for specified confidence level
% and holding period, using an analytical solution. 
%
% The first argument is the stock price, the second is the strike price, the third 
% is the risk-free rate, the fourth is the mean return, the fifth is volatility,  
% the sixth is the term to maturity, the seventh is the confidence level and the last is 
% the holding period. Rates are expressed in annualised terms and periods in days.
% 
% Amount invested is positive (negative) if option position is long (short).
%
% NB: cl and hp are scalars.
%
% Reference: John Hull, "Options, futures, and other derivatives," 4th edition
% Upper Saddle River, NJ: Prentice Hall, 2000, chapter 11. 
%
% Revised by Kevin Dowd, February 28, 2005.
% *****************************************************************************************
%
% Simplify notation
%
t=maturity/360;
hp=hp/360.
%
current_option_price=blackscholesputprice(stock_price,strike, r, sigma, t)
%
s_star=exp(log(stock_price)+(mu-(sigma^2)/2)*hp-norminv(cl,0,1)*sigma*sqrt(hp))
% Critical future stock price; see Hull, p. 238
future_option_price_star=blackscholesputprice(s_star,strike, r, sigma, t-hp)
% Critical future option price
y=-current_option_price+future_option_price_star;
