function y=pcaprelim(rho)
% PCAPRELIM Preliminary principal components analysis
%
% Function estimates the principal components of a return data set, and generates a 
% scree plot showing the percentage variability explained by each. 
%
% This data set is entered as a matrix - each row is interpreted as a set of daily observations, 
% and each column as the returns to each position in a portfolio. 
%
% Revised by Kevin Dowd, February 11th, 2001.
% *****************************************************************************************
%
% Establish correlation matrix
%
corr_matrix=[
rho^0 rho^1 rho^2 rho^3 rho^4 rho^5 rho^6 rho^7 rho^8 rho^9;
rho^1 rho^0 rho^1 rho^2 rho^3 rho^4 rho^5 rho^6 rho^7 rho^8;
rho^2 rho^1 rho^0 rho^1 rho^2 rho^3 rho^4 rho^5 rho^6 rho^7; 
rho^3 rho^2 rho^1 rho^0 rho^1 rho^2 rho^3 rho^4 rho^5 rho^6;
rho^4 rho^3 rho^2 rho^1 rho^0 rho^1 rho^2 rho^3 rho^4 rho^5;
rho^5 rho^4 rho^3 rho^2 rho^1 rho^0 rho^1 rho^2 rho^3 rho^4;
rho^6 rho^5 rho^4 rho^3 rho^2 rho^1 rho^0 rho^1 rho^2 rho^3;
rho^7 rho^6 rho^5 rho^4 rho^3 rho^2 rho^1 rho^0 rho^1 rho^2;
rho^8 rho^7 rho^6 rho^5 rho^4 rho^3 rho^2 rho^1 rho^0 rho^1;
rho^9 rho^8 rho^7 rho^6 rho^5 rho^4 rho^3 rho^2 rho^1 rho^0;
];
%
mu=zeros(1,10);
sigma=corr_matrix;
%
% Random number generation
%
state = 137; randn('state', state);
returns=mvnrnd(mu,sigma,1000);
%
% Principal components estimation
%
[pcs,newdata,variances]=princomp(returns);
%
% Scree plot
%
n=1000;
subplot(2,1,1);
percent_explained=100*variances/sum(variances);
% pareto(percent_explained)
bar(percent_explained)
ylabel('(%)','Fontweight','bold')
cum_variance(1)=percent_explained(1);
for i=2:length(variances)
    cum_variance(i)=percent_explained(i)+cum_variance(i-1);
end
t=0:10;
subplot(2,1,2);
plot(t,[0,cum_variance])
xlabel('Principal component','Fontweight','bold')
ylabel('(%)','Fontweight','bold')
title('Explanatory Power of the Principal Components','Fontweight','bold')
